# LiteLLM Proxy Enterprise Features - Readme

## Overview

This directory contains enterprise features used on the LiteLLM proxy.

## Format

Create a file for every group of endpoints (e.g. `key_management_endpoints.py`, `user_management_endpoints.py`, etc.)

If there is a broader semantic group of endpoints, create a folder for that group (e.g. `management_endpoints`, `auth_endpoints`, etc.)
